{ lib, pkgs, ... }:

with pkgs; callPackage python3Packages.buildPythonPackage rec {
  pname = "xborders";
  version = "3.4"; # in version.txt
  src = fetchFromGitHub {
    owner = "deter0";
    repo = "xborder";
    rev = "d840ed649e92b7ad399cdb1a30aeca7d09f2c08f";
    sha256 = "sha256-Q2WWXekUL/OOr/OBqJOZbAHaWURbP+coBVp206uPSNY=";
  };
  buildInputs = [ libwnck gtk3 libnotify ];
  nativeBuildInputs = [ wrapGAppsHook gobject-introspection ];
  propagatedBuildInputs = with python3Packages; [ pycairo requests pygobject3 ];
  preBuild = ''
    sed '52,58!d' ${pname}
    sed -i '51 a\    return ${version}' ${pname}
    cat >setup.py <<'EOF'
    from setuptools import setup
    setup(
      name='${pname}',
      version='${version}',
      author='deter0',
      description='${meta.description}',
      install_requires=['pycairo', 'requests', 'PyGObject'],
      scripts=[
        '${pname}',
      ],
    )
    EOF
  '';
  meta = with lib; {
    description = "Active window border replacement for window managers.";
    homepage = "https://github.com/deter0/xborder";
    license = licenses.unlicense;
    maitainers = with maintainers; [ elnudev ];
    platforms = platforms.linux;
  };
}
